==> papermage-0.16.0.tar.gz: papermage-0.16.0/papermage/magelib/__init__.py <==
"""

Needs to be imported in this order.

@kylel

"""


from .box import Box
from .layer import Layer
from .document import (
    AbstractsFieldName,
    AlgorithmsFieldName,
    AuthorsFieldName,
    BibliographiesFieldName,
    BlocksFieldName,
    CaptionsFieldName,
    Document,
    Prediction,
    EntitiesFieldName,
    EquationsFieldName,
    FiguresFieldName,
    FootersFieldName,
    FootnotesFieldName,
    HeadersFieldName,
    ImagesFieldName,
    KeywordsFieldName,
    ListsFieldName,
    MetadataFieldName,
    PagesFieldName,
    ParagraphsFieldName,
    RelationsFieldName,
    RowsFieldName,
    SectionsFieldName,
    SentencesFieldName,
    SymbolsFieldName,
    TablesFieldName,
    TitlesFieldName,
    TokensFieldName,
    WordsFieldName,
)
from .entity import Entity
from .image import Image
from .indexer import EntityBoxIndexer, EntitySpanIndexer
from .metadata import Metadata
from .span import Span

__all__ = [
    "AbstractsFieldName",
    "AlgorithmsFieldName",
    "AuthorsFieldName",
    "BibliographiesFieldName",
    "BlocksFieldName",
    "Box",
    "Prediction",
    "CaptionsFieldName",
    "Document",
    "EntitiesFieldName",
    "Entity",
    "EntityBoxIndexer",
    "EntitySpanIndexer",
    "EquationsFieldName",
    "FiguresFieldName",
    "FootersFieldName",
    "FootnotesFieldName",
    "HeadersFieldName",
    "Image",
    "ImagesFieldName",
    "KeywordsFieldName",
    "KeywordsFieldName",
    "Layer",
    "ListsFieldName",
    "Metadata",
    "MetadataFieldName",
    "PagesFieldName",
    "ParagraphsFieldName",
    "RelationsFieldName",
    "RowsFieldName",
    "SectionsFieldName",
    "SentencesFieldName",
    "Span",
    "SymbolsFieldName",
    "TablesFieldName",
    "TitlesFieldName",
    "TokensFieldName",
    "WordsFieldName",
]

==> papermage-0.19.0.tar.gz: papermage-0.19.0/papermage/magelib/__init__.py <==
"""

Needs to be imported in this order.

@kylel

"""

from .box import Box
from .document import Document, Prediction
from .entity import Entity
from .image import Image
from .indexer import EntityBoxIndexer, EntitySpanIndexer
from .layer import Layer
from .metadata import Metadata
from .names import (
    AbstractsFieldName,
    AlgorithmsFieldName,
    AuthorsFieldName,
    BibliographiesFieldName,
    BlocksFieldName,
    CaptionsFieldName,
    EntitiesFieldName,
    EquationsFieldName,
    FiguresFieldName,
    FootersFieldName,
    FootnotesFieldName,
    HeadersFieldName,
    ImagesFieldName,
    KeywordsFieldName,
    ListsFieldName,
    MetadataFieldName,
    PagesFieldName,
    ParagraphsFieldName,
    RelationsFieldName,
    RowsFieldName,
    SectionsFieldName,
    SentencesFieldName,
    SymbolsFieldName,
    TablesFieldName,
    TitlesFieldName,
    TokensFieldName,
    WordsFieldName,
)
from .span import Span

__all__ = [
    "AbstractsFieldName",
    "AlgorithmsFieldName",
    "AuthorsFieldName",
    "BibliographiesFieldName",
    "BlocksFieldName",
    "Box",
    "Prediction",
    "CaptionsFieldName",
    "Document",
    "EntitiesFieldName",
    "Entity",
    "EntityBoxIndexer",
    "EntitySpanIndexer",
    "EquationsFieldName",
    "FiguresFieldName",
    "FootersFieldName",
    "FootnotesFieldName",
    "HeadersFieldName",
    "Image",
    "ImagesFieldName",
    "KeywordsFieldName",
    "KeywordsFieldName",
    "Layer",
    "ListsFieldName",
    "Metadata",
    "MetadataFieldName",
    "PagesFieldName",
    "ParagraphsFieldName",
    "RelationsFieldName",
    "RowsFieldName",
    "SectionsFieldName",
    "SentencesFieldName",
    "Span",
    "SymbolsFieldName",
    "TablesFieldName",
    "TitlesFieldName",
    "TokensFieldName",
    "WordsFieldName",
]
